@@ -18,7 +18,9 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-from gettext import gettext as _
+import config
+import gettext
+gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
 import cupshelpers
 import urllib
 
@@ -75,6 +77,11 @@ class PhysicalDevice:
 
         if hostport:
             (host, port) = urllib.splitport (hostport)
+
+        if type (host) == unicode:
+            host = host.encode ('utf-8')
+        if type (dnssdhost) == unicode:
+            dnssdhost = dnssdhost.encode ('utf-8')
         return host, dnssdhost
 
     def add_device (self, device):
