@@ -32,7 +32,9 @@ cups.require ("1.9.60")
 import authconn
 from debug import *
 import debug
-from gettext import gettext as _
+import gettext
+gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
+
 
 ######
 ###### An asynchronous libcups API using IPP with a separate worker
@@ -88,7 +90,7 @@ class _IPPConnectionThread(threading.Thread):
                                     port=self.port,
                                     encryption=self._encryption)
             self._reply (None)
-        except RuntimeError, e:
+        except RuntimeError as e:
             conn = None
             self._error (e)
 
@@ -127,7 +129,7 @@ class _IPPConnectionThread(threading.Thread):
 
                     self._queue.task_done ()
                     self._reply (None)
-                except RuntimeError, e:
+                except RuntimeError as e:
                     debugprint ("...failed")
                     self._queue.task_done ()
                     self._error (e)
@@ -146,7 +148,7 @@ class _IPPConnectionThread(threading.Thread):
 
                 debugprint ("...success")
                 self._reply (result)
-            except Exception, e:
+            except Exception as e:
                 debugprint ("...failure (%s)" % repr (e))
                 self._error (e)
 
@@ -354,7 +356,7 @@ class _IPPAuthOperation:
             self._reconnect = False
             self._reconnected = True
             debugprint ("%s (_error_handler): reconnecting (as %s)..." %
-                        (self, self_user))
+                        (self, self._user))
             conn.reconnect (self._user,
                             reply_handler=self._reconnect_reply,
                             error_handler=self._reconnect_error)
@@ -688,11 +690,11 @@ if __name__ == "__main__":
                                            error_handler=self.connect_failed)
 
         def connected (self, conn, result):
-            debugprint ("Success: %s" % result)
+            debugprint ("Success: %s" % repr (result))
             self.get_devices_button.set_sensitive (True)
 
         def connect_failed (self, conn, exc):
-            debugprint ("Exc %s" % exc)
+            debugprint ("Exc %s" % repr (exc))
             self.get_devices_button.set_sensitive (False)
             self.conn.destroy ()
 
@@ -707,7 +709,7 @@ if __name__ == "__main__":
                 debugprint ("Ignoring stale reply")
                 return
 
-            debugprint ("Got devices: %s" % result)
+            debugprint ("Got devices: %s" % repr (result))
             self.get_devices_button.set_sensitive (True)
 
         def get_devices_error (self, conn, exc):
@@ -715,7 +717,7 @@ if __name__ == "__main__":
                 debugprint ("Ignoring stale error")
                 return
 
-            debugprint ("Error getting devices: %s" % exc)
+            debugprint ("Error getting devices: %s" % repr (exc))
             self.get_devices_button.set_sensitive (True)
 
     UI ()
