@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2013 Red Hat, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -18,6 +18,7 @@
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import threading
+import config
 import cups
 import cupspk
 from gi.repository import GLib
@@ -26,7 +27,8 @@ from gi.repository import Gtk
 import os
 from errordialogs import *
 from debug import *
-from gettext import gettext as _
+import gettext
+gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
 N_ = lambda x: x
 
 cups.require("1.9.60")
@@ -170,7 +172,7 @@ class Connection:
         self._connect ()
 
     def _begin_operation (self, operation):
-        debugprint ("%s: Operation += %s" % (self, repr (operation)))
+        debugprint ("%s: Operation += %s" % (self, operation))
         self._operation_stack.append (operation)
 
     def _end_operation (self):
@@ -243,7 +245,8 @@ class Connection:
                         # Authentication failed, but we aren't told that.
                         raise cups.IPPError (cups.IPP_NOT_AUTHORIZED, '')
                 break
-            except cups.IPPError, (e, m):
+            except cups.IPPError as e:
+                (e, m) = e.args
                 if self._use_pk and m == 'pkcancel':
                     raise cups.IPPError (0, _("Operation canceled"))
 
@@ -271,9 +274,10 @@ class Connection:
                     if self._cancel and not self._cannot_auth:
                         raise cups.IPPError (0, _("Operation canceled"))
 
-                    debugprint ("%s: %s" % (e, m))
+                    debugprint ("%s: %s" % (e, repr (m)))
                     raise
-            except cups.HTTPError, (s,):
+            except cups.HTTPError as e:
+                (s,) = e.args
                 if not self._cancel:
                     self._failed (s == cups.HTTP_FORBIDDEN)
                 else:
@@ -286,7 +290,7 @@ class Connection:
             Gdk.threads_enter ()
 
         try:
-            msg = _("CUPS server error (%s)") % self._operation_stack[0]
+            msg = (_("CUPS server error (%s)") % self._operation_stack[0])
         except IndexError:
             msg = _("CUPS server error")
 
@@ -461,7 +465,7 @@ class Connection:
         # Prompt.
         if len (self._operation_stack) > 0:
             try:
-                title = _("Authentication (%s)") % self._operation_stack[0]
+                title = (_("Authentication (%s)") % self._operation_stack[0])
             except IndexError:
                 title = _("Authentication")
 
