@@ -25,7 +25,6 @@ import dbus
 import dbus.glib
 import dbus.service
 from gi.repository import Notify
-import gettext
 from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gdk
@@ -56,7 +55,9 @@ try:
 except ImportError:
     USE_KEYRING=False
 
-from gettext import gettext as _
+import gettext
+gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
+
 from statereason import StateReason
 
 pkgdata = config.pkgdatadir
@@ -140,6 +141,8 @@ class PrinterURIIndex:
         try:
             if connection == None:
                 connection = cups.Connection ()
+            if isinstance(name, bytes):
+                name = name.decode ('utf-8')
 
             r = ['printer-name', 'printer-uri-supported', 'printer-more-info']
             if uri != None:
@@ -497,7 +500,7 @@ class JobViewer (GtkGUI):
 
         if my_jobs:
             if specific_dests:
-                title = _("my jobs on %s") % the_dests.encode ('utf-8')
+                title = _("my jobs on %s") % the_dests
             else:
                 title = _("my jobs")
         else:
@@ -683,16 +686,15 @@ class JobViewer (GtkGUI):
             if visible:
                 w = self.JobsWindow.get_window()
                 aw = self.JobsAttributesWindow.get_window()
-                (s, area, o) = self.statusicon.get_geometry ()
-                w.set_skip_taskbar_hint (True)
-                if aw != None:
-                    aw.set_skip_taskbar_hint (True)
+                (loc, s, area, o) = self.statusicon.get_geometry ()
 
-                w.property_change ("_NET_WM_ICON_GEOMETRY",
-                                   "CARDINAL", 32,
-                                   Gdk.PROP_MODE_REPLACE,
-                                   list (area))
-                self.JobsWindow.iconify ()
+                if loc:
+                    w.set_skip_taskbar_hint (True)
+                    if aw != None:
+                        aw.set_skip_taskbar_hint (True)
+                    self.JobsWindow.iconify ()
+                else:
+                    self.JobsWindow.set_visible (False)
             else:
                 self.JobsWindow.present ()
                 self.JobsWindow.set_skip_taskbar_hint (False)
@@ -893,7 +895,7 @@ class JobViewer (GtkGUI):
             pass
         except RuntimeError:
             pass
-        except cups.IPPError, (e, m):
+        except cups.IPPError:
             pass
 
         # Invalidate the cached status description and redraw the treeview.
@@ -933,9 +935,16 @@ class JobViewer (GtkGUI):
                         keyring_attrs["domain"] = str (group)
                     else:
                         (serverport, rest) = urllib.splithost (rest)
-                        (server, port) = urllib.splitnport (serverport)
-                    keyring_attrs.update ({ "server": str (server.lower ()),
-                                            "protocol": str (scheme)})
+                        if serverport == None:
+                            server = None
+                        else:
+                            (server, port) = urllib.splitnport (serverport)
+
+                    if scheme == None or server == None:
+                        try_keyring = False
+                    else:
+                        keyring_attrs.update ({ "server": str (server.lower ()),
+                                                "protocol": str (scheme)})
 
                 if job in self.authenticated_jobs:
                     # We've already tried to authenticate this job before.
@@ -957,7 +966,8 @@ class JobViewer (GtkGUI):
                         ind = auth_info_required.index ('password')
                         auth_info[ind] = items[0].secret
                     else:
-                        debugprint ("gnomekeyring: look-up result %s" % result)
+                        debugprint ("gnomekeyring: look-up result %s" %
+                                    repr (result))
 
                 if try_keyring and c == None:
                     try:
@@ -977,7 +987,7 @@ class JobViewer (GtkGUI):
                         debugprint ("Automatically authenticated job %d" % job)
                         self.authenticated_jobs.add (job)
                         return
-                    except cups.IPPError, (e, m):
+                    except cups.IPPError:
                         c._end_operation ()
                         nonfatalException ()
                         return
@@ -985,9 +995,10 @@ class JobViewer (GtkGUI):
                         c._end_operation ()
                         nonfatalException ()
 
-                username = pwd.getpwuid (os.getuid ())[0]
-                keyring_attrs["user"] = str (username)
-                self.display_auth_info_dialog (job, keyring_attrs)
+                if data.has_key ('auth_info_required'):
+                    username = pwd.getpwuid (os.getuid ())[0]
+                    keyring_attrs["user"] = str (username)
+                    self.display_auth_info_dialog (job, keyring_attrs)
         self.update_sensitivity ()
 
     def display_auth_info_dialog (self, job, keyring_attrs=None):
@@ -1020,7 +1031,7 @@ class JobViewer (GtkGUI):
 
         dialog.set_prompt (_("Authentication required for "
                              "printing document `%s' (job %d)") %
-                           (data.get('job-name', _("Unknown")).encode ('utf-8'),
+                           (data.get('job-name', _("Unknown")),
                             job))
         self.auth_info_dialogs[job] = dialog
         dialog.connect ('response', self.auth_info_dialog_response)
@@ -1058,7 +1069,8 @@ class JobViewer (GtkGUI):
             remember = dialog.get_remember_password ()
             self.authenticated_jobs.add (jobid)
             self.update_monitor ()
-        except cups.IPPError, (e, m):
+        except cups.IPPError as e:
+            (e, m) = e.args
             self.show_IPP_Error (e, m)
 
         c._end_operation ()
@@ -1092,7 +1104,8 @@ class JobViewer (GtkGUI):
                                                                    val)
                     id = gnomekeyring.item_create_sync (keyring, type, name,
                                                         attrs, secret, True)
-                    debugprint ("keyring: created id %d for %s" % (id, name))
+                    debugprint ("keyring: created id %d for %s" % (repr (id),
+                                                                   name))
             except:
                 nonfatalException ()
 
@@ -1314,7 +1327,8 @@ class JobViewer (GtkGUI):
             c._begin_operation (_("holding job"))
             try:
                 c.setJobHoldUntil (jobid, "indefinite")
-            except cups.IPPError, (e, m):
+            except cups.IPPError as e:
+                (e, m) = e.args
                 if (e != cups.IPP_NOT_POSSIBLE and
                     e != cups.IPP_NOT_FOUND):
                     self.show_IPP_Error (e, m)
@@ -1339,7 +1353,8 @@ class JobViewer (GtkGUI):
             c._begin_operation (_("releasing job"))
             try:
                 c.setJobHoldUntil (jobid, "no-hold")
-            except cups.IPPError, (e, m):
+            except cups.IPPError as e:
+                (e, m) = e.args
                 if (e != cups.IPP_NOT_POSSIBLE and
                     e != cups.IPP_NOT_FOUND):
                     self.show_IPP_Error (e, m)
@@ -1360,7 +1375,8 @@ class JobViewer (GtkGUI):
             for jobid in self.jobids:
                 c.restartJob (jobid)
             del c
-        except cups.IPPError, (e, m):
+        except cups.IPPError as e:
+            (e, m) = e.args
             self.show_IPP_Error (e, m)
             self.update_monitor ()
             return
@@ -1425,7 +1441,8 @@ class JobViewer (GtkGUI):
                         debugprint("Unable to retrieve file from job file")
                         return
 
-            except cups.IPPError, (e, m):
+            except cups.IPPError as e:
+                (e, m) = e.args
                 self.show_IPP_Error (e, m)
                 self.update_monitor ()
                 return
@@ -1442,7 +1459,8 @@ class JobViewer (GtkGUI):
             for jobid in self.jobids:
                 c.moveJob (job_id=jobid, job_printer_uri=job_printer_uri)
             del c
-        except cups.IPPError, (e, m):
+        except cups.IPPError as e:
+            (e, m) = e.args
             self.show_IPP_Error (e, m)
             self.update_monitor ()
             return
@@ -1724,12 +1742,12 @@ class JobViewer (GtkGUI):
         level = reason.get_level ()
         if (level == StateReason.ERROR or
             reason.get_reason () == "connecting-to-device"):
-            urgency = Notify.URGENCY_NORMAL
+            urgency = Notify.Urgency.NORMAL
         else:
-            urgency = Notify.URGENCY_LOW
+            urgency = Notify.Urgency.LOW
 
         (title, text) = reason.get_description ()
-        notification = Notify.Notification (title, text, 'printer')
+        notification = Notify.Notification.new (title, text, 'printer')
         reason.user_notified = True
         notification.set_urgency (urgency)
         if self.notify_has_actions:
@@ -1782,13 +1800,13 @@ class JobViewer (GtkGUI):
                     return
 
         printer = job.get ('job-printer-name', _("Unknown"))
-        notification = Notify.Notification (_("Document printed"),
+        notification = Notify.Notification.new (_("Document printed"),
                                               _("Document `%s' has been sent "
                                                 "to `%s' for printing.") %
-                                              (document.encode ('utf-8'),
-                                               printer.encode ('utf-8')),
+                                              (document,
+                                               printer),
                                               'printer')
-        notification.set_urgency (Notify.URGENCY_LOW)
+        notification.set_urgency (Notify.Urgency.LOW)
         notification.connect ('closed',
                               self.on_completed_job_notification_closed)
         notification.jobid = jobid
@@ -1947,11 +1965,10 @@ class JobViewer (GtkGUI):
                 if notify_text.find ("backend errors") != -1:
                     message = (_("There was a problem sending document `%s' "
                                  "(job %d) to the printer.") %
-                               (document.encode ('utf-8', jobid)))
+                               (document, jobid))
                 elif notify_text.find ("filter errors") != -1:
                     message = _("There was a problem processing document `%s' "
-                                "(job %d).") % (document.encode ('utf-8'),
-                                                jobid)
+                                "(job %d).") % (document, jobid)
                 elif (notify_text.find ("being paused") != -1 or
                       jstate != cups.IPP_JOB_STOPPED):
                     may_be_problem = False
@@ -1959,9 +1976,7 @@ class JobViewer (GtkGUI):
                     # Give up and use the provided message untranslated.
                     message = (_("There was a problem printing document `%s' "
                                  "(job %d): `%s'.") %
-                               (document.encode ('utf-8'),
-                                jobid,
-                                notify_text.encode ('utf-8')))
+                               (document, jobid, notify_text))
 
             if may_be_problem:
                 debugprint ("Problem detected")
@@ -1989,7 +2004,7 @@ class JobViewer (GtkGUI):
                         name = event['printer-name']
                         markup += ' '
                         markup += (_("The printer called `%s' has "
-                                     "been disabled.") % name.encode ('utf-8'))
+                                     "been disabled.") % name)
                 except KeyError:
                     pass
 
@@ -2243,7 +2258,8 @@ class JobViewer (GtkGUI):
                             os.environ["TZ"] = old_tz
 
                         local = time.localtime (simpletime)
-                        state = _("Held until %s") % time.strftime ("%X", local)
+                        state = (_("Held until %s") %
+                                 time.strftime ("%X", local))
                 except ValueError:
                     pass
             if until == "day-time":
