@@ -187,7 +187,7 @@ class GetBestDriversRequest:
 
             g_killtimer.remove_hold ()
             self.reply_handler (map (lambda x: (x, fit[x]), ppdnamelist))
-        except Exception, e:
+        except Exception as e:
             try:
                 g_killtimer.remove_hold ()
             except:
@@ -217,7 +217,7 @@ class GroupPhysicalDevicesRequest:
                 resolver.resolve (reply_handler=self._group)
             else:
                 self._group ()
-        except Exception, e:
+        except Exception as e:
             g_killtimer.remove_hold ()
             self.error_handler (e)
 
@@ -245,7 +245,7 @@ class GroupPhysicalDevicesRequest:
 
             g_killtimer.remove_hold ()
             self.reply_handler (uris_by_phys)
-        except Exception, e:
+        except Exception as e:
             g_killtimer.remove_hold ()
             self.error_handler (e)
 
@@ -505,15 +505,16 @@ def _client_demo ():
 
 if __name__ == '__main__':
     import ppdippstr
+    import config
     import gettext
+    gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
+
     import locale
     try:
         locale.setlocale (locale.LC_ALL, "")
     except:
         pass
 
-    gettext.textdomain (config.PACKAGE)
-    gettext.bindtextdomain (config.PACKAGE, config.localedir)
     ppdippstr.init ()
     Gdk.threads_init ()
     from dbus.glib import DBusGMainLoop
